@@ -49,7 +49,7 @@ class BarbarianAutomation(val civInfo: Civilization) {
 
     private fun automateCombatUnit(unit: MapUnit) {
         // 1 - Try pillaging to restore health (barbs don't auto-heal)
-        if (unit.health < 50 && UnitAutomation.tryPillageImprovement(unit)) return
+        if (unit.health < 50 && UnitAutomation.tryPillageImprovement(unit, true) && unit.currentMovement == 0f) return
 
         // 2 - trying to upgrade
         if (UnitAutomation.tryUpgradeUnit(unit)) return
@@ -60,7 +60,9 @@ class BarbarianAutomation(val civInfo: Civilization) {
         if (!unit.isCivilian() && BattleHelper.tryAttackNearbyEnemy(unit)) return
 
         // 4 - trying to pillage tile or route
-        if (UnitAutomation.tryPillageImprovement(unit)) return
+        while (UnitAutomation.tryPillageImprovement(unit)) {
+            if (unit.currentMovement == 0f) return
+        }
 
         // 6 - wander
         UnitAutomation.wander(unit)
