@@ -1,7 +1,7 @@
 package com.unciv.logic.automation.unit
 
-import com.unciv.logic.city.City
 import com.unciv.logic.civilization.Civilization
+import com.unciv.logic.civilization.diplomacy.RelationshipLevel
 import com.unciv.models.Spy
 import com.unciv.models.SpyAction
 import kotlin.random.Random
@@ -15,7 +15,7 @@ class EspionageAutomation(val civInfo: Civilization) {
 
     private val getCivsToStealFromSorted: List<Civilization> =
         civsToStealFrom.sortedBy { otherCiv -> civInfo.espionageManager.spyList
-            .count { it.isDoingWork() && it.getLocation()?.civ == otherCiv }
+            .count { it.isDoingWork() && it.getCityOrNull()?.civ == otherCiv }
         }.toList()
 
     private val cityStatesToRig: List<Civilization> by lazy {
@@ -49,6 +49,7 @@ class EspionageAutomation(val civInfo: Civilization) {
             val randomCity = civInfo.gameInfo.getCities().filter { spy.canMoveTo(it) }.toList().randomOrNull()
             spy.moveTo(randomCity)
         }
+        spies.forEach { checkIfShouldStageCoup(it) }
     }
 
     /**
@@ -80,4 +81,16 @@ class EspionageAutomation(val civInfo: Civilization) {
         spy.moveTo(civInfo.cities.filter { spy.canMoveTo(it) }.randomOrNull())
         return spy.action == SpyAction.CounterIntelligence
     }
+    
+    private fun checkIfShouldStageCoup(spy: Spy) {
+        if (!spy.canDoCoup()) return
+        if (spy.getCoupChanceOfSuccess(false) < .7) return
+        val allyCiv = spy.getCity().civ.getAllyCiv()?.let { civInfo.gameInfo.getCivilization(it) }
+        // Don't coup ally city-states
+        if (allyCiv != null && civInfo.getDiplomacyManager(allyCiv).isRelationshipLevelGE(RelationshipLevel.Friend)) return
+        val spies = civInfo.espionageManager.spyList
+        val randomSeed = spies.size + spies.indexOf(spy) + civInfo.gameInfo.turns
+        val randomAction = Random(randomSeed).nextInt(100)
+        if (randomAction < 20) spy.setAction(SpyAction.Coup, 1)
+    }
 }
