@@ -29,7 +29,7 @@ import kotlin.math.min
 import kotlin.math.roundToInt
 import kotlin.random.Random
 
-class TileDataMap:HashMap<Vector2, MapGenTileData>() {
+class TileDataMap : HashMap<Vector2, MapGenTileData>() {
 
     /** Adds numbers to tileData in a similar way to closeStartPenalty, but for different types */
     fun placeImpact(type: MapRegions.ImpactType, tile: Tile, radius: Int) {
@@ -679,8 +679,8 @@ class MapRegions (val ruleset: Ruleset) {
         // As usual, if there are any relevant json definitions, assume they are complete
         val fallbackStrategic = ruleset.tileResources.values.none {
             it.resourceType == ResourceType.Strategic &&
-                    it.uniqueObjects.any { unique -> unique.isOfType(UniqueType.ResourceWeighting) } ||
-                    it.uniqueObjects.any { unique -> unique.isOfType(UniqueType.MinorDepositWeighting) }
+                    it.hasUnique(UniqueType.ResourceWeighting) ||
+                    it.hasUnique(UniqueType.MinorDepositWeighting)
         }
         /* There are a couple competing/complementary distribution systems at work here. First, major
            deposits are placed according to a frequency defined in the terrains themselves, for each
@@ -710,15 +710,16 @@ class MapRegions (val ruleset: Ruleset) {
         for (resource in ruleset.tileResources.values.filter {
             it.resourceType == ResourceType.Strategic ||
             it.resourceType == ResourceType.Bonus }) {
+
             for (rule in resource.uniqueObjects.filter { unique ->
-                unique.isOfType(UniqueType.ResourceFrequency) ||
-                unique.isOfType(UniqueType.ResourceWeighting) ||
-                unique.isOfType(UniqueType.MinorDepositWeighting) }) {
+                unique.type == UniqueType.ResourceFrequency ||
+                unique.type == UniqueType.ResourceWeighting ||
+                unique.type == UniqueType.MinorDepositWeighting }) {
                 // Weed out some clearly impossible rules straight away to save time later
                 if (rule.conditionals.any { conditional ->
-                        (conditional.isOfType(UniqueType.ConditionalOnWaterMaps) && !usingArchipelagoRegions) ||
-                        (conditional.isOfType(UniqueType.ConditionalInRegionOfType) && regions.none { region -> region.type == conditional.params[0] }) ||
-                        (conditional.isOfType(UniqueType.ConditionalInRegionExceptOfType) && regions.all { region -> region.type == conditional.params[0] })
+                        (conditional.type == UniqueType.ConditionalOnWaterMaps && !usingArchipelagoRegions) ||
+                        (conditional.type == UniqueType.ConditionalInRegionOfType && regions.none { region -> region.type == conditional.params[0] }) ||
+                        (conditional.type == UniqueType.ConditionalInRegionExceptOfType && regions.all { region -> region.type == conditional.params[0] })
                     } )
                     continue
                 val simpleRule = anonymizeUnique(rule)
@@ -792,7 +793,7 @@ class MapRegions (val ruleset: Ruleset) {
                 continue
             val weightings = strategicResources.map {
                 if (fallbackStrategic) {
-                    if (tile.lastTerrain.name in it.terrainsCanBeFoundOn) 1f else 0f
+                    if (it.generatesNaturallyOn(tile)) 1f else 0f
                 } else {
                     val uniques = it.getMatchingUniques(UniqueType.MinorDepositWeighting, conditionalTerrain).toList()
                     uniques.sumOf { unique -> unique.params[0].toInt() }.toFloat()
@@ -822,10 +823,10 @@ class MapRegions (val ruleset: Ruleset) {
         for (resource in strategicResources) {
             val extraNeeded = min(2, regions.size - totalPlaced[resource]!!)
             if (extraNeeded > 0) {
-                if (isWaterOnlyResource(resource, ruleset))
-                    MapRegionResources.tryAddingResourceToTiles(tileData, resource, extraNeeded, tileMap.values.asSequence().filter { it.isWater }.shuffled(), respectImpacts = true)
-                else
-                    MapRegionResources.tryAddingResourceToTiles(tileData, resource, extraNeeded, landList.asSequence(), respectImpacts = true)
+                val tilesToAddTo = if (!isWaterOnlyResource(resource, ruleset)) landList.asSequence()
+                else tileMap.values.asSequence().filter { it.isWater }.shuffled()
+
+                MapRegionResources.tryAddingResourceToTiles(tileData, resource, extraNeeded, tilesToAddTo, respectImpacts = true)
             }
         }
 
