@@ -18,7 +18,6 @@ import com.unciv.utils.Concurrency
 import com.unciv.utils.Dispatcher
 import com.unciv.utils.debug
 import com.unciv.utils.launchOnThreadPool
-import com.unciv.utils.withGLContext
 import kotlinx.coroutines.CoroutineScope
 import kotlinx.coroutines.Job
 import kotlinx.coroutines.coroutineScope
@@ -42,7 +41,7 @@ private val FILE_UPDATE_THROTTLE_PERIOD = Duration.ofSeconds(60)
 /**
  * Provides multiplayer functionality to the rest of the game.
  *
- * See the file of [com.unciv.logic.multiplayer.MultiplayerGameAdded] for all available [EventBus] events.
+ * See the file of [com.unciv.logic.multiplayer.HasMultiplayerGameName] for all available [EventBus] events.
  */
 class OnlineMultiplayer {
     private val files = UncivGame.Current.files
@@ -113,7 +112,7 @@ class OnlineMultiplayer {
         }
     }
 
-    private suspend fun updateSavesFromFiles() {
+    private fun updateSavesFromFiles() {
         val saves = files.getMultiplayerSaves()
 
         val removedSaves = savedGames.keys - saves.toSet()
@@ -129,8 +128,6 @@ class OnlineMultiplayer {
 
 
     /**
-     * Fires [MultiplayerGameAdded]
-     *
      * @throws FileStorageRateLimitReached if the file storage backend can't handle any additional actions for a time
      */
     suspend fun createGame(newGame: GameInfo) {
@@ -139,8 +136,6 @@ class OnlineMultiplayer {
     }
 
     /**
-     * Fires [MultiplayerGameAdded]
-     *
      * @param gameName if this is null or blank, will use the gameId as the game name
      * @return the final name the game was added under
      * @throws FileStorageRateLimitReached if the file storage backend can't handle any additional actions for a time
@@ -157,23 +152,20 @@ class OnlineMultiplayer {
         addGame(gamePreview, saveFileName)
     }
 
-    private suspend fun addGame(newGame: GameInfo) {
+    private fun addGame(newGame: GameInfo) {
         val newGamePreview = newGame.asPreview()
         addGame(newGamePreview, newGamePreview.gameId)
     }
 
-    private suspend fun addGame(preview: GameInfoPreview, saveFileName: String) {
+    private fun addGame(preview: GameInfoPreview, saveFileName: String) {
         val fileHandle = files.saveGame(preview, saveFileName)
         return addGame(fileHandle, preview)
     }
 
-    private suspend fun addGame(fileHandle: FileHandle, preview: GameInfoPreview? = null) {
+    private fun addGame(fileHandle: FileHandle, preview: GameInfoPreview? = null) {
         debug("Adding game %s", fileHandle.name())
         val game = OnlineMultiplayerGame(fileHandle, preview, if (preview != null) Instant.now() else null)
         savedGames[fileHandle] = game
-        withGLContext {
-            EventBus.send(MultiplayerGameAdded(game.name))
-        }
     }
 
     fun getGameByName(name: String): OnlineMultiplayerGame? {
@@ -249,7 +241,6 @@ class OnlineMultiplayer {
         } else if (onlinePreview != null && hasNewerGameState(preview, onlinePreview)) {
             onlineGame.doManualUpdate(preview)
         }
-        UncivGame.Current.settings.autoPlay.stopAutoPlay()
         UncivGame.Current.loadGame(gameInfo)
     }
 
@@ -279,8 +270,6 @@ class OnlineMultiplayer {
 
     /**
      * Deletes the game from disk, does not delete it remotely.
-     *
-     * Fires [MultiplayerGameDeleted]
      */
     fun deleteGame(multiplayerGame: OnlineMultiplayerGame) {
         deleteGame(multiplayerGame.fileHandle)
@@ -293,7 +282,6 @@ class OnlineMultiplayer {
 
         debug("Deleting game %s with id %s", fileHandle.name(), game.preview?.gameId)
         savedGames.remove(game.fileHandle)
-        Concurrency.runOnGLThread { EventBus.send(MultiplayerGameDeleted(game.name)) }
     }
 
     /**
