@@ -48,8 +48,10 @@ data class StateForConditionals(
         fun Civilization?.hash() = this?.civName?.hashCode() ?: 0
         fun City?.hash() = this?.id?.hashCode() ?: 0
         fun Tile?.hash() = this?.position?.hashCode() ?: 0
-        fun MapUnit?.hash() = (this?.name?.hashCode() ?: 0) + 17 * this?.currentTile.hash()
-        fun ICombatant?.hash() = (this?.getName()?.hashCode() ?: 0) + 17 * this?.getTile().hash()
+        fun MapUnit?.hash() = if (this == null) 0 else name.hashCode() + (if (hasTile()) 17 * currentTile.hash() else 0)
+        fun ICombatant?.hash() = if (this == null) 0
+            else if (this is MapUnitCombatant) unit.hash()  // line only serves as `lateinit currentTile not initialized` guard
+            else getName().hashCode() + 17 * getTile().hash()
         fun CombatAction?.hash() = this?.name?.hashCode() ?: 0
         fun Region?.hash() = this?.rect?.hashCode() ?: 0
 
