@@ -114,6 +114,7 @@ enum class UniqueParameterType(
             if (CityFilter.isKnownValue(parameterText, ruleset)) return true
             return false
         }
+        override fun getTranslationWriterStringsForOutput() = setOf("City")
     },
 
     /** Implemented by [MapUnit.matchesFilter][com.unciv.logic.map.mapunit.MapUnit.matchesFilter] */
@@ -606,7 +607,26 @@ enum class UniqueParameterType(
         }
     },
 
-    /** Used by [UniqueType.HiddenWithoutVictoryType], implementation in Civilopedia and OverviewScreen */
+    /** Implemtented by [com.unciv.models.ruleset.Policy.matchesFilter] */
+    PolicyFilter("policyFilter", "Oligarchy", "The name of any policy") {
+        private val knownValues = Constants.all
+
+        override fun isKnownValue(parameterText: String, ruleset: Ruleset): Boolean {
+            if (parameterText in knownValues) return true
+            if (parameterText in ruleset.policies) return true
+            if (ruleset.policies.values.any { it.hasUnique(parameterText) }) return true
+            return false
+        }
+
+        override fun getErrorSeverity(
+            parameterText: String,
+            ruleset: Ruleset
+        ): UniqueType.UniqueParameterErrorSeverity? {
+            return getErrorSeverityForFilter(parameterText, ruleset)
+        }
+    },
+
+    /** Used by [UniqueType.HiddenWithoutVictoryType], implementation in Civilopedia, OverviewScreen and to exclude e.g. from Quests */
     VictoryT("victoryType", "Domination", "The name of any victory type: 'Neutral', 'Cultural', 'Diplomatic', 'Domination', 'Scientific', 'Time'") {
         override fun getErrorSeverity(
             parameterText: String,
@@ -674,7 +694,7 @@ enum class UniqueParameterType(
     open fun isKnownValue(parameterText: String, ruleset: Ruleset): Boolean = false
 
     fun getErrorSeverityForFilter(parameterText: String, ruleset: Ruleset): UniqueType.UniqueParameterErrorSeverity? {
-        val isKnown = MultiFilter.multiFilter(parameterText, {isKnownValue(it, ruleset)}, true)
+        val isKnown = MultiFilter.multiFilter(parameterText, { isKnownValue(it, ruleset) }, true)
         if (isKnown) return null
         return UniqueType.UniqueParameterErrorSeverity.PossibleFilteringUnique
     }
