@@ -2,7 +2,6 @@ package com.unciv.models.ruleset.validation
 
 import com.badlogic.gdx.Gdx
 import com.badlogic.gdx.graphics.Color
-import com.badlogic.gdx.graphics.g2d.TextureAtlas.TextureAtlasData
 import com.unciv.Constants
 import com.unciv.json.fromJsonFile
 import com.unciv.json.json
@@ -10,6 +9,7 @@ import com.unciv.logic.map.tile.RoadStatus
 import com.unciv.models.metadata.BaseRuleset
 import com.unciv.models.ruleset.BeliefType
 import com.unciv.models.ruleset.Building
+import com.unciv.models.ruleset.IRulesetObject
 import com.unciv.models.ruleset.Ruleset
 import com.unciv.models.ruleset.RulesetCache
 import com.unciv.models.ruleset.nation.Nation
@@ -20,14 +20,18 @@ import com.unciv.models.ruleset.unique.StateForConditionals
 import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.models.ruleset.unit.BaseUnit
 import com.unciv.models.ruleset.unit.Promotion
+import com.unciv.models.stats.INamed
 import com.unciv.models.stats.Stats
 import com.unciv.models.tilesets.TileSetCache
 import com.unciv.models.tilesets.TileSetConfig
+import com.unciv.ui.images.AtlasPreview
 
 class RulesetValidator(val ruleset: Ruleset) {
 
     private val uniqueValidator = UniqueValidator(ruleset)
 
+    private val textureNamesCache by lazy { AtlasPreview(ruleset) }
+
     fun getErrorList(tryFixUnknownUniques: Boolean = false): RulesetErrorList {
         // When no base ruleset is loaded - references cannot be checked
         if (!ruleset.modOptions.isBaseRuleset) return getNonBaseRulesetErrorList(tryFixUnknownUniques)
@@ -49,10 +53,10 @@ class RulesetValidator(val ruleset: Ruleset) {
         addPromotionErrorsRulesetInvariant(lines, tryFixUnknownUniques)
         addResourceErrorsRulesetInvariant(lines, tryFixUnknownUniques)
 
-        /**********************  **********************/
-        // e.g. json configs complete and parseable
-        // Check for mod or Civ_V_GnK to avoid running the same test twice (~200ms for the builtin assets)
-        if (ruleset.folderLocation != null) checkTilesetSanity(lines)
+        // Tileset tests - e.g. json configs complete and parseable
+        checkTilesetSanity(lines)
+
+        checkCivilopediaText(lines)
 
         return lines
     }
@@ -87,11 +91,14 @@ class RulesetValidator(val ruleset: Ruleset) {
         addEventErrors(lines, tryFixUnknownUniques)
         addCityStateTypeErrors(tryFixUnknownUniques, lines)
 
+        // Tileset tests - e.g. json configs complete and parseable
         // Check for mod or Civ_V_GnK to avoid running the same test twice (~200ms for the builtin assets)
         if (ruleset.folderLocation != null || ruleset.name == BaseRuleset.Civ_V_GnK.fullName) {
             checkTilesetSanity(lines)
         }
 
+        checkCivilopediaText(lines)
+
         return lines
     }
 
@@ -144,7 +151,7 @@ class RulesetValidator(val ruleset: Ruleset) {
 
     private fun addEventErrors(lines: RulesetErrorList,
                                tryFixUnknownUniques: Boolean) {
-        // A Difficulty is not a IHasUniques, so not suitable as sourceObject
+        // An Event is not a IHasUniques, so not suitable as sourceObject
         for (event in ruleset.events.values) {
             for (choice in event.choices) {
                 for (unique in choice.conditionObjects + choice.triggeredUniqueObjects)
@@ -401,6 +408,8 @@ class RulesetValidator(val ruleset: Ruleset) {
         for (improvement in ruleset.tileImprovements.values) {
             if (improvement.techRequired != null && !ruleset.technologies.containsKey(improvement.techRequired!!))
                 lines.add("${improvement.name} requires tech ${improvement.techRequired} which does not exist!", sourceObject = improvement)
+            if (improvement.replaces != null && !ruleset.tileImprovements.containsKey(improvement.replaces))
+                lines.add("${improvement.name} replaces ${improvement.replaces} which does not exist!", sourceObject = improvement)
             for (terrain in improvement.terrainsCanBeBuiltOn)
                 if (!ruleset.terrains.containsKey(terrain) && terrain != "Land" && terrain != "Water")
                     lines.add("${improvement.name} can be built on terrain $terrain which does not exist!", sourceObject = improvement)
@@ -817,21 +826,11 @@ class RulesetValidator(val ruleset: Ruleset) {
             lines.add("Fallback tileset invalid: ${unknownFallbacks.joinToString()}", RulesetErrorSeverity.Warning, sourceObject = null)
     }
 
-    private fun getTilesetNamesFromAtlases(): Set<String> {
-        // This partially duplicates code in ImageGetter.getAvailableTilesets, but we don't want to reload that singleton cache.
-
-        // Our builtin rulesets have no folderLocation, in that case cheat and apply knowledge about
-        // where the builtin Tileset textures are (correct would be to parse Atlases.json):
-        val files = ruleset.folderLocation?.list("atlas")?.asSequence()
-            ?: sequenceOf(Gdx.files.internal("Tilesets.atlas"))
-        // Next, we need to cope with this running without GL context (unit test) - no TextureAtlas(file)
-        return files
-            .flatMap { file ->
-                TextureAtlasData(file, file.parent(), false).regions.asSequence()
-                    .filter { it.name.startsWith("TileSets/") && !it.name.contains("/Units/") }
-            }.map { it.name.split("/")[1] }
+    private fun getTilesetNamesFromAtlases() =
+        textureNamesCache
+            .filter { it.startsWith("TileSets/") && !it.contains("/Units/") }
+            .map { it.split("/")[1] }
             .toSet()
-    }
 
     private fun checkPromotionCircularReferences(lines: RulesetErrorList) {
         fun recursiveCheck(history: HashSet<Promotion>, promotion: Promotion, level: Int) {
@@ -856,4 +855,21 @@ class RulesetValidator(val ruleset: Ruleset) {
             recursiveCheck(hashSetOf(), promotion, 0)
         }
     }
+
+    private fun checkCivilopediaText(lines: RulesetErrorList) {
+        for (sourceObject in ruleset.allICivilopediaText()) {
+            for ((index, line) in sourceObject.civilopediaText.withIndex()) {
+                for (error in line.unsupportedReasons(this)) {
+                    val nameText = (sourceObject as? INamed)?.name?.plus("'s ") ?: ""
+                    val text = "(${sourceObject::class.java.simpleName}) ${nameText}civilopediaText line ${index + 1}: $error"
+                    lines.add(text, RulesetErrorSeverity.WarningOptionsOnly, sourceObject as? IRulesetObject, null)
+                }
+            }
+        }
+    }
+
+    fun uncachedImageExists(name: String): Boolean {
+        if (ruleset.folderLocation == null) return false // Can't check in this case
+        return textureNamesCache.imageExists(name)
+    }
 }
