@@ -76,11 +76,6 @@ class ModManagementScreen private constructor(
         const val maxAllowedPreviewImageSize = 200f
         /** Github queries use this limit */
         const val amountPerPage = 100
-
-        val modsToHideAsUrl by lazy {
-            val blockedModsFile = Gdx.files.internal("jsons/ManuallyBlockedMods.json")
-            json().fromJsonFile(Array<String>::class.java, blockedModsFile)
-        }
     }
 
     // Since we're `RecreateOnResize`, preserve the portrait/landscape mode for our lifetime
@@ -318,11 +313,6 @@ class ModManagementScreen private constructor(
             if (onlineModInfo.containsKey(repo.name))
                 continue // we already got this mod in a previous download, since one has been added in between
 
-            // Mods we have manually decided to remove for instability are removed here
-            // If at some later point these mods are updated, we should definitely remove
-            // this piece of code. This is a band-aid, not a full solution.
-            if (repo.html_url in modsToHideAsUrl) continue
-
             val installedMod = RulesetCache.values.firstOrNull { it.name == repo.name }
             val isUpdatedVersionOfInstalledMod = installedMod?.modOptions?.let {
                 it.lastUpdated != "" && it.lastUpdated != repo.pushed_at
