@@ -24,13 +24,7 @@ class MapOptionsTable(private val newGameScreen: NewGameScreen, isReset: Boolean
         val mapTypes = arrayListOf(MapGeneratedMainType.generated, MapGeneratedMainType.randomGenerated)
         if (savedMapOptionsTable.isNotEmpty()) mapTypes.add(MapGeneratedMainType.custom)
 
-        // Pre-select custom if any map saved within last 15 minutes
-        val chooseCustom = !isReset && (
-                savedMapOptionsTable.recentlySavedMapExists() ||
-                savedMapOptionsTable.isNotEmpty() && mapParameters.type == MapGeneratedMainType.custom && mapParameters.name.isNotEmpty()
-            )
-        val mapTypeDefault = if (chooseCustom) MapGeneratedMainType.custom else MapGeneratedMainType.generated
-        mapTypeSelectBox = TranslatedSelectBox(mapTypes, mapTypeDefault, BaseScreen.skin)
+        mapTypeSelectBox = TranslatedSelectBox(mapTypes, MapGeneratedMainType.generated, BaseScreen.skin)
 
         fun updateOnMapTypeChange() {
             mapTypeSpecificTable.clear()
@@ -38,6 +32,7 @@ class MapOptionsTable(private val newGameScreen: NewGameScreen, isReset: Boolean
                 MapGeneratedMainType.custom -> {
                     mapParameters.type = MapGeneratedMainType.custom
                     mapTypeSpecificTable.add(savedMapOptionsTable)
+                    savedMapOptionsTable.activateCustomMaps()
                     newGameScreen.unlockTables()
                 }
                 MapGeneratedMainType.generated -> {
@@ -45,7 +40,6 @@ class MapOptionsTable(private val newGameScreen: NewGameScreen, isReset: Boolean
                     mapParameters.type = generatedMapOptionsTable.mapTypeSelectBox.selected.value
                     mapTypeSpecificTable.add(generatedMapOptionsTable)
                     newGameScreen.unlockTables()
-
                 }
                 MapGeneratedMainType.randomGenerated -> {
                     mapParameters.name = ""
@@ -57,7 +51,7 @@ class MapOptionsTable(private val newGameScreen: NewGameScreen, isReset: Boolean
             newGameScreen.updateTables()
         }
 
-        // activate once, so when we had a file map before we'll have the right things set for another one
+        // activate once, so the MapGeneratedMainType.generated controls show
         updateOnMapTypeChange()
 
         mapTypeSelectBox.onChange { updateOnMapTypeChange() }
