@@ -1,3 +1,4 @@
+
 import com.unciv.build.BuildConfig
 import com.unciv.build.BuildConfig.gdxVersion
 
@@ -11,6 +12,19 @@ sourceSets {
     }
 }
 
+kotlin {
+    jvmToolchain(17)
+
+    target {
+        compilations.all {
+            kotlinOptions.jvmTarget = JavaVersion.VERSION_1_8.toString()
+        }
+    }
+}
+java {
+    targetCompatibility = JavaVersion.VERSION_1_8
+}
+
 dependencies {
     // See https://libgdx.com/news/2021/07/devlog-7-lwjgl3#do-i-need-to-do-anything-else
     api("com.badlogicgames.gdx:gdx-lwjgl3-glfw-awt-macos:$gdxVersion")
@@ -142,7 +156,7 @@ for (platform in Platform.values()) {
 
             val platformNameForPackrCmd =
                     if (platform == Platform.MacOS) "mac"
-                    else platform.name.toLowerCase()
+                    else platform.name.lowercase()
 
             val command = "java -jar $rootDir/packr-all-4.0.0.jar" +
                     " --platform $platformNameForPackrCmd" +
